@@ -1,7 +1,12 @@
 import pandas as pd
 import json
 
-csv = pd.read_csv('faker_ids/id.csv')
+import os
+this_dir, this_filename = os.path.split(__file__)
+DATA_PATH = os.path.join(this_dir, "id.csv")
+csv = pd.read_csv(DATA_PATH)
+
+# csv = pd.read_csv('faker_ids/id.csv')
 csv = csv.values.tolist()
 
 def get_ids(n):
